"""Basic database schema.


Revision ID: fa4b74d9c734
Revises: 147a1cfccba4
Create Date: 2017-09-15 12:29:00.820902

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision = 'fa4b74d9c734'
down_revision = None

JSON = sa.Text().with_variant(postgresql.JSONB, 'postgresql')


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('operation',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('crawler', sa.String(), nullable=False),
    sa.Column('run_id', sa.String(), nullable=False),
    sa.Column('name', sa.String(), nullable=True),
    sa.Column('status', sa.String(), nullable=True),
    sa.Column('started_at', sa.DateTime(), nullable=True),
    sa.Column('ended_at', sa.DateTime(), nullable=True),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_index(op.f('ix_operation_crawler'), 'operation', ['crawler'], unique=False)
    op.create_index(op.f('ix_operation_run_id'), 'operation', ['run_id'], unique=False)
    op.create_table('tag',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('crawler', sa.String(length=255), nullable=False),
    sa.Column('run_id', sa.String(length=50), nullable=True),
    sa.Column('key', sa.String(), nullable=False),
    sa.Column('value', JSON, nullable=False),
    sa.Column('timestamp', sa.DateTime(), nullable=True),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_index(op.f('ix_tag_crawler'), 'tag', ['crawler'], unique=False)
    op.create_index(op.f('ix_tag_key'), 'tag', ['key'], unique=False)
    op.create_index(op.f('ix_tag_run_id'), 'tag', ['run_id'], unique=False)
    op.create_table('event',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('level', sa.String(), nullable=False),
    sa.Column('operation_id', sa.Integer(), nullable=False),
    sa.Column('error_type', sa.String(), nullable=True),
    sa.Column('error_message', sa.String(), nullable=True),
    sa.Column('error_details', sa.String(), nullable=True),
    sa.Column('timestamp', sa.DateTime(), nullable=True),
    sa.ForeignKeyConstraint(['operation_id'], ['operation.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_index(op.f('ix_event_level'), 'event', ['level'], unique=False)
    op.create_table('result',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('crawler', sa.String(), nullable=False),
    sa.Column('operation_id', sa.Integer(), nullable=True),
    sa.Column('prev_stage', sa.String(), nullable=False),
    sa.Column('next_stage', sa.String(), nullable=False),
    sa.Column('data', JSON, nullable=False),
    sa.Column('timestamp', sa.DateTime(), nullable=True),
    sa.ForeignKeyConstraint(['operation_id'], ['operation.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_index(op.f('ix_result_crawler'), 'result', ['crawler'], unique=False)
    op.create_index(op.f('ix_result_next_stage'), 'result', ['next_stage'], unique=False)
    op.create_index(op.f('ix_result_prev_stage'), 'result', ['prev_stage'], unique=False)
    # ### end Alembic commands ###


def downgrade():
    pass
